@@ -31,6 +31,7 @@ class QAction;
 class QMenu;
 class QLabel;
 class QLineEdit;
+class QSplitter;
 
 namespace KTextEditor {
     class View;
@@ -50,7 +51,7 @@ class HgCommitDialog : public DialogBase
     Q_OBJECT
 
 public:
-    HgCommitDialog(QWidget *parent = 0);
+    explicit HgCommitDialog(QWidget *parent = 0);
 
 private slots:
     /**
@@ -82,7 +83,7 @@ private:
 private:
     QString                      m_hgBaseDir;
 
-    QPlainTextEdit              *m_commitMessage;
+    KTextEditor::Document       *m_commitMessage;
     HgStatusList                *m_statusList;
 
     KTextEditor::View           *m_fileDiffView;
@@ -97,6 +98,9 @@ private:
     QMenu                       *m_branchMenu;
     QMenu                       *m_copyMessageMenu;
 
+    QSplitter                   *m_verticalSplitter; // Divides file list and editors
+    QSplitter                   *m_horizontalSplitter; // Divides commit editor and diff editor
+
     /** What will commit do with branch. 
      *
      * CloseBranch: Close the current branch
@@ -115,7 +119,7 @@ class NewBranchDialog : public QDialog
         Q_OBJECT
 
     public:
-        NewBranchDialog(QWidget *parent = 0);
+        explicit NewBranchDialog(QWidget *parent = 0);
         QString getBranchName() const;
 
     private slots:
